@@ -4,10 +4,11 @@
 #
 # ------------------------------------------------------------------------------
 
-from .SwitchCase import run_tests
+from .SwitchCase import test_switch_case
 from .base import TestLogging, Test_base
 from .debug import Test_debug
 from .test_tk import run_all
+from .test_files import test_files
 
 
 
@@ -15,8 +16,9 @@ from .test_tk import run_all
 __all__ = ['RUN_TESTS']
 
 def RUN_TESTS():
-    # Test_base()
-    # TestLogging()
-    # run_tests()
-    # Test_debug()
+    test_files()
+    Test_base()
+    TestLogging()
+    # test_switch_case()
+    Test_debug()
     run_all()
